==> conf_ini_g-2024.9.tar.gz: conf_ini_g-2024.9/package/conf_ini_g/interface/window/parameter/value.py <==
"""
Copyright CNRS/Inria/UniCA
Contributor(s): Eric Debreuve (eric.debreuve@cnrs.fr) since 2021
SEE COPYRIGHT NOTICE BELOW
"""

import dataclasses as d
import typing as h
from abc import ABC as abstract_class_t
from abc import abstractmethod

from babelwidget.main import backend_t
from str_to_obj.api.type import annotation_t, type_t


class _do_not_set_value:
    pass


DO_NOT_SET_VALUE = _do_not_set_value()


@d.dataclass(repr=False, eq=False)
class value_wgt_a(abstract_class_t):
    messenger: d.InitVar[h.Any | None]
    message: d.InitVar[str | h.Sequence[str] | None]
    backend: d.InitVar[backend_t | None]
    _AcknowledgeNewValue: h.Callable[[], None] | None = d.field(
        init=False, default=None
    )

    def __post_init__(
        self,
        messenger: h.Any | None,
        message: str | h.Sequence[str] | None,
        backend: backend_t,
    ) -> None:
        """"""
        if messenger is None:
            return

        if isinstance(messenger, h.Sequence):
            if isinstance(message, str):
                message = messenger.__len__() * (message,)
            for who, what in zip(messenger, message):
                backend.AddMessageCanal(who, what, self.AcknowledgeNewValue)
        else:
            backend.AddMessageCanal(messenger, message, self.AcknowledgeNewValue)

    def SetNewValueAcknowledgementFunction(
        self, Function: h.Callable[[], None], /
    ) -> None:
        """"""
        self._AcknowledgeNewValue = Function

    def AcknowledgeNewValue(self) -> None:
        """"""
        if self._AcknowledgeNewValue is not None:
            self._AcknowledgeNewValue()

    @classmethod
    @abstractmethod
    def NewForSpecification(
        cls, stripe: type_t | annotation_t | None, backend: backend_t
    ) -> h.Self: ...

    @abstractmethod
    def Assign(self, value: h.Any, stripe: type_t | annotation_t | None, /) -> None: ...

    @abstractmethod
    def Text(self) -> str: ...


"""
COPYRIGHT NOTICE

This software is governed by the CeCILL  license under French law and
abiding by the rules of distribution of free software.  You can  use,
modify and/ or redistribute the software under the terms of the CeCILL
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info".

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability.

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or
data to be ensured and,  more generally, to use and operate it in the
same conditions as regards security.

The fact that you are presently reading this means that you have had
knowledge of the CeCILL license and that you accept its terms.

SEE LICENCE NOTICE: file README-LICENCE-utf8.txt at project source root.

This software is being developed by Eric Debreuve, a CNRS employee and
member of team Morpheme.
Team Morpheme is a joint team between Inria, CNRS, and UniCA.
It is hosted by the Centre Inria d'Université Côte d'Azur, Laboratory
I3S, and Laboratory iBV.

CNRS: https://www.cnrs.fr/index.php/en
Inria: https://www.inria.fr/en/
UniCA: https://univ-cotedazur.eu/
Centre Inria d'Université Côte d'Azur: https://www.inria.fr/en/centre/sophia/
I3S: https://www.i3s.unice.fr/en/
iBV: http://ibv.unice.fr/
Team Morpheme: https://team.inria.fr/morpheme/
"""

==> conf_ini_g-2024.13.tar.gz: conf_ini_g-2024.13/package/conf_ini_g/interface/window/parameter/value.py <==
"""
Copyright CNRS/Inria/UniCA
Contributor(s): Eric Debreuve (eric.debreuve@cnrs.fr) since 2021
SEE COPYRIGHT NOTICE BELOW
"""

import dataclasses as d
import typing as h
from abc import ABC as abstract_class_t
from abc import abstractmethod

from babelwidget.main import backend_t
from str_to_obj.api.type import annotation_t, type_t


class _do_not_set_value:
    pass


DO_NOT_SET_VALUE = _do_not_set_value()


@d.dataclass(repr=False, eq=False)
class value_wgt_a(abstract_class_t):
    messenger: d.InitVar[h.Any | None]
    message: d.InitVar[str | h.Sequence[str] | None]
    backend: d.InitVar[backend_t | None]
    _AcknowledgeNewValue: h.Callable[[], None] | None = d.field(
        init=False, default=None
    )

    def __post_init__(
        self,
        messenger: h.Any | None,
        message: str | h.Sequence[str] | None,
        backend: backend_t,
    ) -> None:
        """"""
        if messenger is None:
            return

        if isinstance(messenger, h.Sequence):
            if isinstance(message, str):
                message = messenger.__len__() * (message,)
            for who, what in zip(messenger, message):
                backend.AddMessageCanal(who, what, self.AcknowledgeNewValue)
        else:
            backend.AddMessageCanal(messenger, message, self.AcknowledgeNewValue)

    def SetNewValueAcknowledgementFunction(
        self, Function: h.Callable[[], None] | None, /
    ) -> None:
        """"""
        self._AcknowledgeNewValue = Function

    def AcknowledgeNewValue(self) -> None:
        """"""
        if self._AcknowledgeNewValue is not None:
            self._AcknowledgeNewValue()

    @classmethod
    @abstractmethod
    def NewForSpecification(
        cls, stripe: type_t | annotation_t | None, backend: backend_t
    ) -> h.Self: ...

    @abstractmethod
    def Assign(self, value: h.Any, stripe: type_t | annotation_t | None, /) -> None: ...

    @abstractmethod
    def Text(self) -> str: ...


"""
COPYRIGHT NOTICE

This software is governed by the CeCILL  license under French law and
abiding by the rules of distribution of free software.  You can  use,
modify and/ or redistribute the software under the terms of the CeCILL
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info".

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability.

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or
data to be ensured and,  more generally, to use and operate it in the
same conditions as regards security.

The fact that you are presently reading this means that you have had
knowledge of the CeCILL license and that you accept its terms.

SEE LICENCE NOTICE: file README-LICENCE-utf8.txt at project source root.

This software is being developed by Eric Debreuve, a CNRS employee and
member of team Morpheme.
Team Morpheme is a joint team between Inria, CNRS, and UniCA.
It is hosted by the Centre Inria d'Université Côte d'Azur, Laboratory
I3S, and Laboratory iBV.

CNRS: https://www.cnrs.fr/index.php/en
Inria: https://www.inria.fr/en/
UniCA: https://univ-cotedazur.eu/
Centre Inria d'Université Côte d'Azur: https://www.inria.fr/en/centre/sophia/
I3S: https://www.i3s.unice.fr/en/
iBV: http://ibv.unice.fr/
Team Morpheme: https://team.inria.fr/morpheme/
"""
